#
# spec file for package python-html2text
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-html2text
Version:        2015.4.14
Release:        4.1
Url:            https://github.com/Alir3z4/html2text/
Summary:        Turn HTML into equivalent Markdown-structured text
License:        GPL-3.0
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/h/html2text/html2text-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-unittest2
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
html2text is a Python script that converts a page of HTML into clean,
easy-to-read plain ASCII text. Better yet, that ASCII also happens to
be valid Markdown (a text-to-HTML format).

%prep
%setup -q -n html2text-%{version}
# remove useless shebang
sed -i '/^#!/d' html2text/__init__.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/html2text %{buildroot}%{_bindir}/html2text-python%{py_ver}

%check
python setup.py test

%files
%defattr(-,root,root,-)
%doc COPYING README.md AUTHORS.rst ChangeLog.rst
%{_bindir}/html2text-python%{py_ver}
%{python_sitelib}/*

%changelog
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to version 2015.4.14:
  * Feature #59: Write image tags with height and width attrs as
    raw html to retain dimensions
- additional changes from version 2015.4.13:
  * Feature #56: Treat '-' file parameter as stdin.
  * Feature #57: Retain escaping of html except within code or pre
    tags.
- additional changes from version 2015.2.18:
  * Fix #38: Anchor tags with empty text or with `<img>` tags
    inside are no longer stripped.
- additional changes from version 2014.12.29:
  * Feature #51: Add single line break option.
- additional changes from version 2014.12.24:
  * Feature #49: Added a images_to_alt option to discard images and
    keep only their alt.
  * Feature #50: Protect links, surrounding them with angle
    brackets to avoid breaking...
  * Feature: Add ``setup.cfg`` file.
- additional changes from version 2014.12.5:
  * Feature: Update `README.md` with usage examples.
  * Fix #35: Remove `py_modules` from `setup.py`.
  * Fix #36: Excludes tests from being installed as a separate
    module.
  * Fix #37: Don't hardcode the path to the installed binary.
  * Fix: Readme typo in running cli.
  * Feature #40: Extract cli part to ``cli`` module.
  * Feature #42: Bring python version compatibility to
    ``compat.py`` module.
  * Feature #41: Extract utility/helper methods to ``utils`` module
  * Fix #45: Does not accept standard input when running under
    Python 3.
  * Feature: Clean up ``ChangeLog.rst`` for version and date
    numbers.
- additional changes from version 2014.9.25:
  * Feature #29, #27: Add simple table support with bypass option.
  * Fix #20: Replace project website with:
    http://alir3z4.github.io/html2text/
- additional changes from version 2014.9.8:
  * Fix #28: missing ``html2text`` package in installation.
- additional changes from version 2014.9.7:
  * Fix ``unicode``/``type`` error in memory leak unit-test.
  * Feature #16: Remove ``install_deps.py``.
  * Feature #17: Add status badges via pypin.
  * Feature #18: Add ``Python`` ``3.4`` to travis config file.
  * Feature #19: Bring ``html2text`` to a separate module and take
    out the ``conf``/``constant`` variables.
  * Feature #21: Remove meta vars from ``html2text.py`` file header
  * Fix: Fix TypeError when parsing tags like <img src='foo' alt>.
    Fixed in #25.
- additional changes from version 2014.7.3:
  * Fix #8: Remove ``How to do a release`` section from README.md.
  * Fix #11: Include test directory markdown, html files.
  * Fix #13:  memory leak in using ``handle`` while keeping the old
    instance of ``html2text``.
- additional changes from version 2014.4.5:
  * Fix #1: Add ``ChangeLog.rst`` file.
  * Fix #2: Add ``AUTHORS.rst`` file.
- update URL to maintainer homepage
- drop html2text-entrypoints.patch: rename the script instead
- update package description
- add unittest2 to buildrequire for the tests
- add %%check to run the tests during build
- install the script as html2text-python%%{py_ver}
- add AUTHORS.rst and ChangeLog.rst to documentation
- remove useless shebang in __init__.py
* Sun Feb  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed installation of .py file in /usr/bin; An upstream mistake
    and a conflict betwenn html2text.py in python_sitelib and in
    bindir when an external project tries to import it.
* Mon Oct 28 2013 speilicke@suse.com
- Add html2text-entrypoints.patch:
  + Fix entry point colliding with /usr/bin/html2text
- Spec cleanup
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Jan  7 2012 alexandre@exatati.com.br
- Update to 3.200.3:
  - Sorry, no changelog atm.
* Fri Jan  6 2012 alexandre@exatati.com.br
- Update to 3.200.2:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200.1:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200:
  - Sorry, no changelog atm.
* Thu Nov 24 2011 alexandre@exatati.com.br
- COPYING file on tarball, not outside it.
* Thu Nov 24 2011 saschpe@suse.de
- Fix bnc#732039, add a COPYING file and set license to SDPX style
  (GPL-3.0)
* Wed Nov  9 2011 alexandre@exatati.com.br
- Update to 3.101:
  - Sorry, no changelog atm.
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 3.02:
  * Upstream provides no changes
- BuildRequire more modern python-distribute instead of python-setuptools
- Fixed non-executable script rpmlint warning
* Tue Feb 15 2011 alexandre@exatati.com.br
- Update to 3.01.
* Tue Dec 21 2010 alexandre@exatati.com.br
- Initial package (2.38) for openSUSE generated with py2pack.
